# Django-apitoken

**Django app that helps manage tokens for a RESTfull API.**

[![build-status-image]][travis]

# Overview

Django-apitoken is a django app that helps manage API apitokens..

# Requirements

* Python (2.7, 3.4)
* Django (1.6, 1.8)

# Installation

Install using `pip`...

    pip install django-apitoken

Add `'apitoken'` to your `INSTALLED_APPS` setting.

    INSTALLED_APPS = (
        ...
        'apitoken',
    )

More docs to come...

That's it, we're done!

[build-status-image]: https://secure.travis-ci.org/simonluijk/django-apitoken.png?branch=master
[travis]: http://travis-ci.org/simonluijk/django-apitoken?branch=master
